aboutsummaryrefslogtreecommitdiff
path: root/Emby.Server.Implementations/Chapters/ChapterManager.cs
diff options
context:
space:
mode:
authorSeven Rats <79296037+sevenrats@users.noreply.github.com>2026-05-03 06:18:20 -0400
committerGitHub <noreply@github.com>2026-05-03 12:18:20 +0200
commitf5f75ed2e1b10dc1f4e55d5cdd9dd7fd69ea8f2b (patch)
tree8049df344dbcf64dd35ec2bae5a9bd1ef9c3b1a1 /Emby.Server.Implementations/Chapters/ChapterManager.cs
parentdf6f706c2f632b9e1eeeabccf5511ab24f317633 (diff)
feat/audiobook_chapters (#16518)
feat/audiobook_chapters
Diffstat (limited to 'Emby.Server.Implementations/Chapters/ChapterManager.cs')
-rw-r--r--Emby.Server.Implementations/Chapters/ChapterManager.cs21
1 files changed, 16 insertions, 5 deletions
diff --git a/Emby.Server.Implementations/Chapters/ChapterManager.cs b/Emby.Server.Implementations/Chapters/ChapterManager.cs
index d09ed30ae3..79ab29b87c 100644
--- a/Emby.Server.Implementations/Chapters/ChapterManager.cs
+++ b/Emby.Server.Implementations/Chapters/ChapterManager.cs
@@ -7,6 +7,7 @@ using System.Threading.Tasks;
using Jellyfin.Extensions;
using MediaBrowser.Controller.Chapters;
using MediaBrowser.Controller.Entities;
+using MediaBrowser.Controller.Entities.Audio;
using MediaBrowser.Controller.IO;
using MediaBrowser.Controller.Library;
using MediaBrowser.Controller.MediaEncoding;
@@ -232,12 +233,22 @@ public class ChapterManager : IChapterManager
}
/// <inheritdoc />
- public void SaveChapters(Video video, IReadOnlyList<ChapterInfo> chapters)
+ public bool Supports(BaseItem item)
+ => item is Video or Audio;
+
+ /// <inheritdoc />
+ public void SaveChapters(BaseItem item, IReadOnlyList<ChapterInfo> chapters)
{
- // Remove any chapters that are outside of the runtime of the video
- var validChapters = chapters.Where(c => c.StartPositionTicks < video.RunTimeTicks).ToList();
- _chapterRepository.SaveChapters(video.Id, validChapters);
- }
+ if (!Supports(item))
+ {
+ _logger.LogWarning("Attempted to save chapters for unsupported item type {Type}: {Name} ({Id})", item.GetType().Name, item.Name, item.Id);
+ return;
+ }
+
+ // Remove any chapters that are outside of the runtime of the item
+ var validChapters = chapters.Where(c => c.StartPositionTicks < item.RunTimeTicks).ToList();
+ _chapterRepository.SaveChapters(item.Id, validChapters);
+}
/// <inheritdoc />
public ChapterInfo? GetChapter(Guid baseItemId, int index)